==> phoenix-thirdparty-2.0.0-src.tar.gz: phoenix-thirdparty-2.0.0/CHANGES.md <==

<!---
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
-->
# PHOENIX Changelog

## Release thirdparty-2.0.0 - Unreleased (as of 2022-04-11)



### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6575](https://issues.apache.org/jira/browse/PHOENIX-6575) | Replace patched commons-cli with original one when a release with CLI-254 is available |  Major | thirdparty |
| [PHOENIX-6641](https://issues.apache.org/jira/browse/PHOENIX-6641) | Bump Guava to 31.0.1 in phoenix-thirdparty |  Major | thirdparty |


### BUG FIXES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6353](https://issues.apache.org/jira/browse/PHOENIX-6353) | Fix phoenix-thirdparty rat warnings, and update CHANGES.md, RELEASE\_NOTES.md |  Minor | thirdparty |


### OTHER:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6648](https://issues.apache.org/jira/browse/PHOENIX-6648) | Change next release version of phoenix-thirdparty to 2.0.0 |  Major | thirdparty |



## Release thirdparty-1.1.0 - Unreleased (as of 2021-01-29)



### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6349](https://issues.apache.org/jira/browse/PHOENIX-6349) | Add and use commons-cli to phoenix-thirdparty |  Major | . |



## Release thirdparty-1.0.0 - Unreleased (as of 2020-10-14)



### SUB-TASKS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6039](https://issues.apache.org/jira/browse/PHOENIX-6039) | Create phoenix-thirdparty main project, and add phoenix-shaded-guava as a subproject |  Major | thirdparty |
| [PHOENIX-6038](https://issues.apache.org/jira/browse/PHOENIX-6038) | Create phoenix-thirdparty git repo |  Major | thirdparty |

==> phoenix-thirdparty-2.1.0-src.tar.gz: phoenix-thirdparty-2.1.0/CHANGES.md <==

<!---
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
-->
# PHOENIX Changelog

## Release thirdparty-2.1.0 - Unreleased (as of 2023-12-13)



### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-7080](https://issues.apache.org/jira/browse/PHOENIX-7080) | Switch phoenix-thirdparty to guava-jre from guava-android |  Major | thirdparty |


### OTHER:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-7142](https://issues.apache.org/jira/browse/PHOENIX-7142) | Bump phoenix-thirdparty version to 2.1 |  Major | thirdparty |
| [PHOENIX-6992](https://issues.apache.org/jira/browse/PHOENIX-6992) | Upgrade Guava to 32.1.1 |  Major | thirdparty |



## Release thirdparty-2.0.0 - Unreleased (as of 2022-04-11)



### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6575](https://issues.apache.org/jira/browse/PHOENIX-6575) | Replace patched commons-cli with original one when a release with CLI-254 is available |  Major | thirdparty |
| [PHOENIX-6641](https://issues.apache.org/jira/browse/PHOENIX-6641) | Bump Guava to 31.0.1 in phoenix-thirdparty |  Major | thirdparty |


### BUG FIXES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6353](https://issues.apache.org/jira/browse/PHOENIX-6353) | Fix phoenix-thirdparty rat warnings, and update CHANGES.md, RELEASE\_NOTES.md |  Minor | thirdparty |


### OTHER:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6648](https://issues.apache.org/jira/browse/PHOENIX-6648) | Change next release version of phoenix-thirdparty to 2.0.0 |  Major | thirdparty |



## Release thirdparty-1.1.0 - Unreleased (as of 2021-01-29)



### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6349](https://issues.apache.org/jira/browse/PHOENIX-6349) | Add and use commons-cli to phoenix-thirdparty |  Major | . |



## Release thirdparty-1.0.0 - Unreleased (as of 2020-10-14)



### SUB-TASKS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [PHOENIX-6039](https://issues.apache.org/jira/browse/PHOENIX-6039) | Create phoenix-thirdparty main project, and add phoenix-shaded-guava as a subproject |  Major | thirdparty |
| [PHOENIX-6038](https://issues.apache.org/jira/browse/PHOENIX-6038) | Create phoenix-thirdparty git repo |  Major | thirdparty |
